# Security Policy

## Supported Versions

Maintaining multiple versions of the library is quite time consuming, so
the majority of the effort is focused on the latest major release.

If you do require a version outside of this chart updated with patch fix,
please [contact me](mailto:github@ricmoo.com).

| Version | Supported                                  | Initial Release   |
| ------- | ------------------------------------------ | ----------------- |
| 6.0.x   | :white_check_mark:                         | 2023-02-02        |
| 5.0.x   | :white_check_mark: (security updates)      | 2020-06-12        |
| 4.0.x   | :x:                                        | 2018-10-01        |
| 3.0.x   | :x:                                        | 2018-03-05        |
| 2.2.x   | :x:                                        | 2018-01-11        |
| 2.1.x   | :x:                                        | 2017-05-22        |
| 2.0.x   | :x:                                        | 2017-04-05        |
| 1.0.x   | :x:                                        | 2016-08-23        |
| 0.0.x   | :x:                                        | 2016-07-14        |


## Reporting a Vulnerability

If you identify a security vulnerability with this library (or any dependency),
please do not hesitate to contact [github@ricmoo.com](mailto:github@ricmoo.com)
immediately.

I try to respond within the same day and will address any concern as quickly
as possible (including code fixes and publishing to NPM).

Any vulnerability will also be published to this file, along with credits,
pertinent information and links to fixes.
